<?php
namespace Drupal\brainfood_api\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Drupal\file\Entity\File;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Entity;
use Drupal\node\Entity\Node;

/**
 * Get all terms in vocabulary and vocabulary description.
 *
 * @RestResource(
 *   id = "brainfood_api_blog",
 *   label = @Translation("BrainFoodBlog"),
 *   uri_paths = {
 *     "canonical" = "/api/v1/blog",
 *   }
 * )
 */
class BrainFoodBlogData extends ResourceBase {

  /**
   * Responds to GET requests.
   *
   * Returns all terms in vocabulary and vocabulary description.
   *
   * @return \Drupal\rest\ResourceResponse
   *   The response containing the user profile.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the user was not found.
   * @throws \Symfony\Component\HttpKernel\Exception\BadRequestHttpException
   *   Thrown when no user was provided.
   */

  public function get() {
    $blogData = array();
    $nids = \Drupal::entityQuery('node')->condition('type','article')->execute();
    // $nodes = Node::loadMultiple($nids);

    foreach($nids as $nid) {
      $result = array();
      $textbook_result = array();
      $age_range_result = array();
      $blog = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      // print_r($blog); exit;
      $date_create = $blog->created->value;
      $date_create = date('d-m-Y H:i:s', $date_create);
      $image_uri = $blog->field_image->entity->getFileUri();
      $image = file_create_url($image_uri);
      $uid = $blog->uid->target_id;
      $user = \Drupal::entityTypeManager()->getStorage('user')->load($uid);
      $user_name = $user->name->value;
      $user_picture_id =  $user->user_picture->entity->getFileUri();
      $user_picture = file_create_url($user_picture_id);

      $body = $blog->body->value;
      $body = str_replace('\r\n','',$body);
      $blogData[] = [
        'title' => $blog->title->value,
        'body' => $body,
        'image' => $image,
        'date_created' => $date_create,
        'user_name' => $user_name,
        'user_picture' => $user_picture,
      ];
    }
    // print_r($blogData); exit;
    return new ResourceResponse($blogData);
  }
}