<?php
namespace Drupal\brainfood_api\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Drupal\file\Entity\File;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Entity;
use Drupal\node\Entity\Node;

/**
 * Get all terms in vocabulary and vocabulary description.
 *
 * @RestResource(
 *   id = "brainfood_api_book",
 *   label = @Translation("BrainFoodBook"),
 *   uri_paths = {
 *     "canonical" = "/api/v1/book",
 *   }
 * )
 */
class BrainFoodBookData extends ResourceBase {

  /**
   * Responds to GET requests.
   *
   * Returns all terms in vocabulary and vocabulary description.
   *
   * @return \Drupal\rest\ResourceResponse
   *   The response containing the user profile.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the user was not found.
   * @throws \Symfony\Component\HttpKernel\Exception\BadRequestHttpException
   *   Thrown when no user was provided.
   */

  public function get() {
    $bookData = array();
    $nids = \Drupal::entityQuery('node')->condition('type','product')->execute();
    // $nodes = Node::loadMultiple($nids);
    // print_r($nids); exit;
    foreach($nids as $nid) {
      $result = array();
      $textbook_result = array();
      $age_range_result = array();
      $book = \Drupal::entityTypeManager()->getStorage('node')->load($nid);
      $image_uri = $book->uc_product_image->entity->getFileUri();
      $image = file_create_url($image_uri);
      $genres = $book->field_genre->getValue();
      if($genres) {
        foreach($genres as $target_id) {
          $genre = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->load($target_id['target_id']);
          $name = $genre->name->value;
          $result[] = [
            'name' => $name,
            'target_id' => $target_id['target_id'],
          ];
        }
      }
      $textbook_id = $book->field_textbooks->target_id;
      if($textbook_id) {
        $textbook = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->load($textbook_id);
        $textbook_result[] = [
          'name' => $textbook->name->value,
          'target_id' => $textbook_id
        ];
      }
      $age_range_id = $book->field_age_range->target_id;
      if($age_range_id) {
        $age_range = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->load($age_range_id);
        $age_range_result[] = [
          'name' => $age_range->name->value,
          'target_id' => $age_range_id
        ];
      }
      $availability = $book->field_availability->value;
      $body = $book->body->value;
      $body = str_replace('\r\n','',$body);
      // print_r($body); exit;
      $bookData[] = [
        'id' => $nid,
        'name' => $book->title->value,
        'body' => $body,
        'image' => $image,
        'price' => $book->price->value,
        'cost' => $book->cost->value,
        'author' => $book->field_author->value,
        'publishing' => $book->field_publishing->value,
        'release' => $book->field_release->value,
        'genre' => $result,
        'sku' => $book->model->value,
        'rating' => $book->field_rating->rating,
        'textbooks' => $textbook_result,
        'age_range' => $age_range_result,
        'availability' => $availability,
      ];
    }
    // print_r($bookData); exit;
    return new ResourceResponse($bookData);
  }
}