<?php
namespace Drupal\custom_breadcrumb\Breadcrumb;

use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Link;
use Drupal\Core\Url;

class CustomNodeBreadcrumbBuilder implements BreadcrumbBuilderInterface {
    use StringTranslationTrait;
    
    /**
     * @inheritDoc
     */
    public function applies(RouteMatchInterface $route_match) {
        $parameters = $route_match->getParameters()->all();
        $node = $route_match->getParameter('node');
        if (isset($parameters['node'])) {
            return $parameters['node']->getType() == 'product'
            || $parameters['node']->getType() == 'article';
        }
        return false;
    }

    /**
     * @inheritDoc
     */
    public function build(RouteMatchInterface $route_match) {
        $breadcrumb = new Breadcrumb();
        $breadcrumb->addCacheContexts(['route']);

        $links[] = Link::createFromRoute($this->t('HOME'), '<front>');

        $node = $route_match->getParameter('node');
        if ($node->getType() == 'product') {
            $link = '/books';
            $links[] = Link::fromTextAndUrl('BOOK', Url::fromUserInput($link));
        }
        if ($node->getType() == 'article') {
            $link = '/blog';
            $links[] = Link::fromTextAndUrl('BLOG', Url::fromUserInput($link));
        }
        $links[] = Link::createFromRoute($node->title->value, 'entity.node.canonical', array('node' => $node->id()));

        return $breadcrumb->setLinks($links);
    }
}